Test data for path_latlon
=========================

Download from https://people.cs.kuleuven.be/wannes.meert/leuvenmapmatching/leuvenmapmatching_testdata2.zip

- `route.gpx`
- `route2.gpx`
- `osm_downloaded.xml`
- `osm_downloaded2.xml`

